import setuptools


setuptools.setup(
    name='lunar_test',
    version='0.0.3',
    author='RimoChan',
    author_email='the@librian.net',
    description='lunar_test',
    long_description=open('readme.md', encoding='utf8').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/RimoChan/lunar-Ci',
    packages=['lunar_test'],
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    install_requires=[
        'lunar-python>=1.0.29',
    ],
    python_requires='>=3.6',
)



import unittest
import datetime

from lunar_python import Lunar


def 咦():
    today = datetime.datetime.today()
    lunar = Lunar.fromYmd(today.year, today.month, today.day)
    # return '诸事不宜' not in lunar.getTimeJi()
    return False


class _(unittest.TestCase):
    def test(self):
        assert 咦(), '今日诸事不宜！'
